@@ -8,10 +8,9 @@
 
 
 from dataclasses import dataclass
-from typing import Type
 
-from detector_connector.detector_http_connector import DetectorHttpConnector
-from detector_connector.detector_kafka_connector import DetectorKafkaConnector, T
+from detector_connector.detector_http_connector import DetectorHttpConnector, DetectorSettingsType
+from detector_connector.detector_kafka_connector import DetectorKafkaConnector, DetectionAnalyzeResultType
 
 
 class DetectorConnector:
@@ -23,8 +22,14 @@ class DetectorConnector:
     class Context(DetectorHttpConnector.Context, DetectorKafkaConnector.Context):
         pass
     
-    def __init__(self, config: Config, context: Context, detector_analyze_result_type: Type[T]) -> None:
-        self.http_connector = DetectorHttpConnector(config=config, context=context)
+    def __init__(self,
+                 config: Config,
+                 context: Context,
+                 detector_analyze_result_type: DetectionAnalyzeResultType,
+                 detector_settings_type: DetectorSettingsType) -> None:
+        self.http_connector = DetectorHttpConnector(config=config,
+                                                    context=context,
+                                                    detector_settings_type=detector_settings_type)
         self.kafka_connector = DetectorKafkaConnector(config=config,
                                                       context=context,
                                                       detector_analyze_result_type=detector_analyze_result_type)
