@@ -34,10 +34,10 @@ class DetectorHttpConnector:
         self._connector = HttpServerConnector(config, context)
         self.detector_settings_type = detector_settings_type
 
-    async def get_settings(self, rtsp_url: str, token: str) -> T:
+    async def get_settings(self, stream_url: str, token: str) -> T:
         payload = {
                 "token": token,
-                "rtsp_url": rtsp_url
+                "stream_url": stream_url
         }
         answer = await self._connector.get("/settings/get",
                                            url_query=payload,
@@ -45,21 +45,21 @@ class DetectorHttpConnector:
 
         return dict_to_dataclass(answer["result"], self.detector_settings_type)
 
-    async def set_settings(self, detector_settings: T, token: str) -> dict[str, Any]:
+    async def set_settings(self, detector_settings: T, token: str) -> T:
         payload = {"token": token}
         payload.update(json.loads(custom_dumps(detector_settings)))
         answer = await self._connector.post_json("/settings/set",
                                                  payload=payload,
                                                  headers=self._construct_headers())
-        return answer["result"]
+        return dict_to_dataclass(answer["result"], self.detector_settings_type)
 
-    async def autotune_settings(self, detection: T, token: str) -> dict[str, Any]:
+    async def autotune_settings(self, detection: T, token: str) -> T:
         payload = {"token": token}
         payload.update({"detection": json.loads(custom_dumps(detection))})
         answer = await self._connector.post_json("/settings/autotune",
                                                  payload=payload,
                                                  headers=self._construct_headers())
-        return answer["result"]
+        return dict_to_dataclass(answer["result"], self.detector_settings_type)
 
     def _construct_headers(self) -> dict[str, str]:
         return {"server_name": self.context.project_name}
